@@ -89,24 +89,25 @@ class Word2vecDataset(Dataset):
 
     def __getitem__(self, idx):
         while True:
-            line = self.input_file.readline()
+            line = self.input_file.readline().strip('\n')
             if not line:
                 self.input_file.seek(0, 0)
-                line = self.input_file.readline()
+                line = self.input_file.readline().strip('\n')
 
             if len(line) > 1:
-                words = line.split(' ')
+                words = [x for x in line.split(' ') if len(x)>1]
                 assert len(words) == self.neg_num+2
-                assert len(words[0].split('_')) == self.side_num
+                assert len(words[0].split('_')) == self.side_num+1
+                print([words[0],words[1],words[2:]])
                 return [words[0],words[1],words[2:]]
 
     @staticmethod
     def collate(batches):
-        all_u = [u for batch in batches for u, _, _ in batch if len(batch) > 0]
+        all_u = [batch[0] for batch in batches if len(batch) > 0]
         all_u = [list(map(int,x.split('_'))) for x in all_u]
-        all_v = [v for batch in batches for _, v, _ in batch if len(batch) > 0]
+        all_v = [batch[1] for batch in batches if len(batch) > 0]
         all_v = [list(map(int,x.split('_'))) for x in all_v]
-        all_neg_v = [neg_v for batch in batches for _, _, neg_v in batch if len(batch) > 0]
+        all_neg_v = [batch[2] for batch in batches if len(batch) > 0]
         all_neg_v = [[list(map(int,x.split('_'))) for x in xx] for xx in all_neg_v]
-
+        print(all_u,all_v,all_neg_v)
         return torch.LongTensor(all_u), torch.LongTensor(all_v), torch.LongTensor(all_neg_v)
